@@ -31,6 +31,8 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
+ximport('Hubzero_Controller');
+
 include_once(JPATH_ROOT . DS . 'components' . DS . 'com_tools' . DS . 'helpers' . DS . 'contribute.php');
 include_once(JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_tools' . DS . 'tables' . DS . 'tool.php');
 include_once(JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_tools' . DS . 'tables' . DS . 'version.php');
@@ -41,11 +43,11 @@ include_once(JPATH_ROOT . DS . 'components' . DS . 'com_resources' . DS . 'helpe
 /**
  * Controller class for contributing a tool
  */
-class ToolsControllerAttachments extends \Hubzero\Component\SiteController
+class ToolsControllerAttachments extends Hubzero_Controller
 {
 	/**
 	 * Determines task being called and attempts to execute it
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function execute()
@@ -53,7 +55,7 @@ class ToolsControllerAttachments extends \Hubzero\Component\SiteController
 		$this->_authorize();
 
 		// Load the com_resources component config
-		$rconfig = JComponentHelper::getParams('com_resources');
+		$rconfig =& JComponentHelper::getParams('com_resources');
 		$this->rconfig = $rconfig;
 
 		parent::execute();
@@ -61,7 +63,7 @@ class ToolsControllerAttachments extends \Hubzero\Component\SiteController
 
 	/**
 	 * Reorder an attachment
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function reorderTask()
@@ -72,17 +74,17 @@ class ToolsControllerAttachments extends \Hubzero\Component\SiteController
 		$move = 'order' . JRequest::getVar('move', 'down');
 
 		// Ensure we have an ID to work with
-		if (!$id)
+		if (!$id) 
 		{
-			$this->setError(JText::_('COM_TOOLS_CONTRIBUTE_NO_CHILD_ID'));
+			$this->setError(JText::_('CONTRIBUTE_NO_CHILD_ID'));
 			$this->displayTask($pid);
 			return;
 		}
 
 		// Ensure we have a parent ID to work with
-		if (!$pid)
+		if (!$pid) 
 		{
-			$this->setError(JText::_('COM_TOOLS_CONTRIBUTE_NO_ID'));
+			$this->setError(JText::_('CONTRIBUTE_NO_ID'));
 			$this->displayTask($pid);
 			return;
 		}
@@ -126,7 +128,7 @@ class ToolsControllerAttachments extends \Hubzero\Component\SiteController
 
 	/**
 	 * Rename an attachment
-	 *
+	 * 
 	 * @return     string
 	 */
 	public function renameTask()
@@ -136,7 +138,7 @@ class ToolsControllerAttachments extends \Hubzero\Component\SiteController
 		$name = JRequest::getVar('name', '');
 
 		// Ensure we have everything we need
-		if ($id && $name != '')
+		if ($id && $name != '') 
 		{
 			$r = new ResourcesResource($this->database);
 			$r->load($id);
@@ -150,16 +152,16 @@ class ToolsControllerAttachments extends \Hubzero\Component\SiteController
 
 	/**
 	 * Save an attachment
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function saveTask()
 	{
 		// Incoming
 		$pid = JRequest::getInt('pid', 0);
-		if (!$pid)
+		if (!$pid) 
 		{
-			$this->setError(JText::_('COM_TOOLS_CONTRIBUTE_NO_ID'));
+			$this->setError(JText::_('CONTRIBUTE_NO_ID'));
 			$this->displayTask($pid);
 			return;
 		}
@@ -169,17 +171,17 @@ class ToolsControllerAttachments extends \Hubzero\Component\SiteController
 		$this->_toolid = $obj->getToolIdFromResource($pid);
 
 		// make sure user is authorized to go further
-		if (!$this->_checkAccess($this->_toolid))
+		if (!$this->_checkAccess($this->_toolid)) 
 		{
-			JError::raiseError(403, JText::_('COM_TOOLS_ALERTNOTAUTH'));
+			JError::raiseError(403, JText::_('ALERTNOTAUTH'));
 			return;
 		}
 
 		// Incoming file
 		$file = JRequest::getVar('upload', '', 'files', 'array');
-		if (!$file['name'])
+		if (!$file['name']) 
 		{
-			$this->setError(JText::_('COM_TOOLS_CONTRIBUTE_NO_FILE'));
+			$this->setError(JText::_('CONTRIBUTE_NO_FILE'));
 			$this->displayTask($pid);
 			return;
 		}
@@ -198,7 +200,7 @@ class ToolsControllerAttachments extends \Hubzero\Component\SiteController
 
 		// Instantiate a new resource object
 		$row = new ResourcesResource($this->database);
-		if (!$row->bind($_POST))
+		if (!$row->bind($_POST)) 
 		{
 			$this->setError($row->getError());
 			$this->displayTask($pid);
@@ -206,31 +208,30 @@ class ToolsControllerAttachments extends \Hubzero\Component\SiteController
 		}
 		$row->title = ($row->title) ? $row->title : $file['name'];
 		$row->introtext = $row->title;
-		$row->created = JFactory::getDate()->toSql();
+		$row->created = date('Y-m-d H:i:s');
 		$row->created_by = $this->juser->get('id');
 		$row->published = 1;
-		$row->publish_up = JFactory::getDate()->toSql();
+		$row->publish_up = date('Y-m-d H:i:s');
 		$row->publish_down = '0000-00-00 00:00:00';
 		$row->standalone = 0;
-		$row->access = 0;
 		$row->path = ''; // make sure no path is specified just yet
 
 		// Check content
-		if (!$row->check())
+		if (!$row->check()) 
 		{
 			$this->setError($row->getError());
 			$this->displayTask($pid);
 			return;
 		}
 		// Store new content
-		if (!$row->store())
+		if (!$row->store()) 
 		{
 			$this->setError($row->getError());
 			$this->displayTask($pid);
 			return;
 		}
 
-		if (!$row->id)
+		if (!$row->id) 
 		{
 			$row->id = $row->insertid();
 		}
@@ -241,40 +242,40 @@ class ToolsControllerAttachments extends \Hubzero\Component\SiteController
 		$path = $this->_buildUploadPath($listdir, '');
 
 		// Make sure the upload path exist
-		if (!is_dir($path))
+		if (!is_dir($path)) 
 		{
 			jimport('joomla.filesystem.folder');
-			if (!JFolder::create($path))
+			if (!JFolder::create($path, 0777)) 
 			{
-				$this->setError(JText::_('COM_TOOLS_UNABLE_TO_CREATE_UPLOAD_PATH'));
+				$this->setError(JText::_('UNABLE_TO_CREATE_UPLOAD_PATH'));
 				$this->displayTask($pid);
 				return;
 			}
 		}
 
 		// Perform the upload
-		if (!JFile::upload($file['tmp_name'], $path . DS . $file['name']))
+		if (!JFile::upload($file['tmp_name'], $path . DS . $file['name'])) 
 		{
-			$this->setError(JText::_('COM_TOOLS_ERROR_UPLOADING'));
-		}
-		else
+			$this->setError(JText::_('ERROR_UPLOADING'));
+		} 
+		else 
 		{
 			// File was uploaded
 			// Check the file type
 			$row->type = $this->_getChildType($file['name']);
 		}
 
-		if (!$row->path)
+		if (!$row->path) 
 		{
 			$row->path = $listdir . DS . $file['name'];
 		}
-		if (substr($row->path, 0, 1) == DS)
+		if (substr($row->path, 0, 1) == DS) 
 		{
 			$row->path = substr($row->path, 1, strlen($row->path));
 		}
 
 		// Store new content
-		if (!$row->store())
+		if (!$row->store()) 
 		{
 			$this->setError($row->getError());
 			$this->displayTask($pid);
@@ -296,11 +297,11 @@ class ToolsControllerAttachments extends \Hubzero\Component\SiteController
 		$assoc->child_id = $row->id;
 		$assoc->ordering = $order;
 		$assoc->grouping = 0;
-		if (!$assoc->check())
+		if (!$assoc->check()) 
 		{
 			$this->setError($assoc->getError());
 		}
-		if (!$assoc->store(true))
+		if (!$assoc->store(true)) 
 		{
 			$this->setError($assoc->getError());
 		}
@@ -312,16 +313,16 @@ class ToolsControllerAttachments extends \Hubzero\Component\SiteController
 
 	/**
 	 * Delete a file
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function deleteTask()
 	{
 		// Incoming parent ID
 		$pid = JRequest::getInt('pid', 0);
-		if (!$pid)
+		if (!$pid) 
 		{
-			$this->setError(JText::_('COM_TOOLS_CONTRIBUTE_NO_ID'));
+			$this->setError(JText::_('CONTRIBUTE_NO_ID'));
 			$this->displayTask($pid);
 			return;
 		}
@@ -331,17 +332,17 @@ class ToolsControllerAttachments extends \Hubzero\Component\SiteController
 		$this->_toolid = $obj->getToolIdFromResource($pid);
 
 		// make sure user is authorized to go further
-		if (!$this->_checkAccess($this->_toolid))
+		if (!$this->_checkAccess($this->_toolid)) 
 		{
-			JError::raiseError(403, JText::_('COM_TOOLS_ALERTNOTAUTH'));
+			JError::raiseError(403, JText::_('ALERTNOTAUTH'));
 			return;
 		}
 
 		// Incoming child ID
 		$id = JRequest::getInt('id', 0);
-		if (!$id)
+		if (!$id) 
 		{
-			$this->setError(JText::_('COM_TOOLS_CONTRIBUTE_NO_CHILD_ID'));
+			$this->setError(JText::_('CONTRIBUTE_NO_CHILD_ID'));
 			$this->displayTask($pid);
 			return;
 		}
@@ -353,9 +354,9 @@ class ToolsControllerAttachments extends \Hubzero\Component\SiteController
 		$row->load($id);
 
 		// Check for stored file
-		if ($row->path == '')
+		if ($row->path == '') 
 		{
-			$this->setError(JText::_('COM_TOOLS_ERROR_MISSING_FILE_PATH'));
+			$this->setError(JText::_('Error: file path not found.'));
 			$this->displayTask($pid);
 			return;
 		}
@@ -368,16 +369,16 @@ class ToolsControllerAttachments extends \Hubzero\Component\SiteController
 		$path = $this->_buildUploadPath($listdir, '');
 
 		// Check if the folder even exists
-		if (!is_dir($path) or !$path)
+		if (!is_dir($path) or !$path) 
 		{
-			$this->setError(JText::_('COM_TOOLS_DIRECTORY_NOT_FOUND'));
-		}
-		else
+			$this->setError(JText::_('DIRECTORY_NOT_FOUND'));
+		} 
+		else 
 		{
 			// Attempt to delete the file
-			if (!JFolder::delete($path))
+			if (!JFile::delete($path)) 
 			{
-				$this->setError(JText::_('COM_TOOLS_UNABLE_TO_DELETE_DIRECTORY'));
+				$this->setError(JText::_('UNABLE_TO_DELETE_DIRECTORY'));
 			}
 
 			// Delete associations to the resource
@@ -393,7 +394,7 @@ class ToolsControllerAttachments extends \Hubzero\Component\SiteController
 
 	/**
 	 * Display a list of attachments
-	 *
+	 * 
 	 * @param      integer $id Resource ID
 	 * @return     void
 	 */
@@ -402,15 +403,15 @@ class ToolsControllerAttachments extends \Hubzero\Component\SiteController
 		$this->view->setLayout('display');
 
 		// Incoming
-		if (!$id)
+		if (!$id) 
 		{
 			$id = JRequest::getInt('rid', 0);
 		}
 
 		// Ensure we have an ID to work with
-		if (!$id)
+		if (!$id) 
 		{
-			JError::raiseError(500, JText::_('COM_TOOLS_CONTRIBUTE_NO_ID'));
+			JError::raiseError(500, JText::_('CONTRIBUTE_NO_ID'));
 			return;
 		}
 
@@ -425,10 +426,12 @@ class ToolsControllerAttachments extends \Hubzero\Component\SiteController
 		$helper->getChildren();
 
 		// get config
-		$this->view->cparams = JComponentHelper::getParams('com_resources');
+		$this->view->cparams =& JComponentHelper::getParams('com_resources');
 		$this->view->path = '';
 		$this->view->children = $helper->children;
 
+		$this->_getStyles($this->_option, 'assets/css/component.css');
+
 		// Set errors to view
 		if ($this->getError())
 		{
@@ -444,14 +447,14 @@ class ToolsControllerAttachments extends \Hubzero\Component\SiteController
 
 	/**
 	 * Build the absolute path to a resource's file upload
-	 *
+	 * 
 	 * @param      string $listdir Primary upload directory
 	 * @param      string $subdir  Sub directory of $listdir
-	 * @return     string
+	 * @return     string 
 	 */
 	private function _buildUploadPath($listdir, $subdir='')
 	{
-		if ($subdir)
+		if ($subdir) 
 		{
 			$subdir = DS . trim($subdir, DS);
 		}
@@ -461,13 +464,13 @@ class ToolsControllerAttachments extends \Hubzero\Component\SiteController
 
 		// Make sure the path doesn't end with a slash
 		$listdir = DS . trim($listdir, DS);
-
+		
 		// Does the beginning of the $listdir match the config path?
-		if (substr($listdir, 0, strlen($base)) == $base)
+		if (substr($listdir, 0, strlen($base)) == $base) 
 		{
 			// Yes - ... this really shouldn't happen
-		}
-		else
+		} 
+		else 
 		{
 			// No - append it
 			$listdir = $base . $listdir;
@@ -479,7 +482,7 @@ class ToolsControllerAttachments extends \Hubzero\Component\SiteController
 
 	/**
 	 * Get the child's type ID based on file extension
-	 *
+	 * 
 	 * @param      string $filename File name
 	 * @return     integer
 	 */
@@ -508,7 +511,7 @@ class ToolsControllerAttachments extends \Hubzero\Component\SiteController
 
 	/**
 	 * Check if user has access
-	 *
+	 * 
 	 * @param      integer $toolid       Tool ID
 	 * @param      boolean $allowAuthors Allow tool authors?
 	 * @return     boolean True if user has access, False if not
@@ -519,17 +522,17 @@ class ToolsControllerAttachments extends \Hubzero\Component\SiteController
 		$obj = new Tool($this->database);
 
 		// allow to view if admin
-		if ($this->config->get('access-manage-component'))
+		if ($this->config->get('access-manage-component')) 
 		{
 			return true;
 		}
 
 		// check if user in tool dev team
-		if ($developers = $obj->getToolDevelopers($toolid))
+		if ($developers = $obj->getToolDevelopers($toolid)) 
 		{
-			foreach ($developers as $dv)
+			foreach ($developers as $dv) 
 			{
-				if ($dv->uidNumber == $this->juser->get('id'))
+				if ($dv->uidNumber == $this->juser->get('id')) 
 				{
 					return true;
 				}
@@ -537,7 +540,7 @@ class ToolsControllerAttachments extends \Hubzero\Component\SiteController
 		}
 
 		// allow access to tool authors
-		if ($allowAuthors)
+		if ($allowAuthors) 
 		{
 			// Nothing here?
 		}
@@ -547,7 +550,7 @@ class ToolsControllerAttachments extends \Hubzero\Component\SiteController
 
 	/**
 	 * Authorization checks
-	 *
+	 * 
 	 * @param      string $assetType Asset type
 	 * @param      string $assetId   Asset id to check against
 	 * @return     void
@@ -555,23 +558,24 @@ class ToolsControllerAttachments extends \Hubzero\Component\SiteController
 	protected function _authorize($assetType='component', $assetId=null)
 	{
 		$this->config->set('access-view-' . $assetType, true);
-		if ($this->juser->get('guest'))
+		if ($this->juser->get('guest')) 
 		{
 			return;
 		}
 
 		// if no admin group is defined, allow superadmin to act as admin
 		// otherwise superadmins can only act if they are also a member of the component admin group
-		if (($admingroup = trim($this->config->get('admingroup', ''))))
+		if (($admingroup = trim($this->config->get('admingroup', '')))) 
 		{
+			ximport('Hubzero_User_Helper');
 			// Check if they're a member of admin group
-			$ugs = \Hubzero\User\Helper::getGroups($this->juser->get('id'));
-			if ($ugs && count($ugs) > 0)
+			$ugs = Hubzero_User_Helper::getGroups($this->juser->get('id'));
+			if ($ugs && count($ugs) > 0) 
 			{
 				$admingroup = strtolower($admingroup);
 				foreach ($ugs as $ug)
 				{
-					if (strtolower($ug->cn) == $admingroup)
+					if (strtolower($ug->cn) == $admingroup) 
 					{
 						$this->config->set('access-manage-' . $assetType, true);
 						$this->config->set('access-admin-' . $assetType, true);
@@ -582,30 +586,44 @@ class ToolsControllerAttachments extends \Hubzero\Component\SiteController
 				}
 			}
 		}
-		else
+		else 
 		{
-			$asset  = $this->_option;
-			if ($assetId)
+			if (version_compare(JVERSION, '1.6', 'ge'))
 			{
-				$asset .= ($assetType != 'component') ? '.' . $assetType : '';
-				$asset .= ($assetId) ? '.' . $assetId : '';
-			}
+				$asset  = $this->_option;
+				if ($assetId)
+				{
+					$asset .= ($assetType != 'component') ? '.' . $assetType : '';
+					$asset .= ($assetId) ? '.' . $assetId : '';
+				}
 
-			$at = '';
-			if ($assetType != 'component')
+				$at = '';
+				if ($assetType != 'component')
+				{
+					$at .= '.' . $assetType;
+				}
+
+				// Admin
+				$this->config->set('access-admin-' . $assetType, $this->juser->authorise('core.admin', $asset));
+				$this->config->set('access-manage-' . $assetType, $this->juser->authorise('core.manage', $asset));
+				// Permissions
+				$this->config->set('access-create-' . $assetType, $this->juser->authorise('core.create' . $at, $asset));
+				$this->config->set('access-delete-' . $assetType, $this->juser->authorise('core.delete' . $at, $asset));
+				$this->config->set('access-edit-' . $assetType, $this->juser->authorise('core.edit' . $at, $asset));
+				$this->config->set('access-edit-state-' . $assetType, $this->juser->authorise('core.edit.state' . $at, $asset));
+				$this->config->set('access-edit-own-' . $assetType, $this->juser->authorise('core.edit.own' . $at, $asset));
+			}
+			else 
 			{
-				$at .= '.' . $assetType;
+				if ($this->juser->authorize($this->_option, 'manage'))
+				{
+					$this->config->set('access-manage-' . $assetType, true);
+					$this->config->set('access-admin-' . $assetType, true);
+					$this->config->set('access-create-' . $assetType, true);
+					$this->config->set('access-delete-' . $assetType, true);
+					$this->config->set('access-edit-' . $assetType, true);
+				}
 			}
-
-			// Admin
-			$this->config->set('access-admin-' . $assetType, $this->juser->authorise('core.admin', $asset));
-			$this->config->set('access-manage-' . $assetType, $this->juser->authorise('core.manage', $asset));
-			// Permissions
-			$this->config->set('access-create-' . $assetType, $this->juser->authorise('core.create' . $at, $asset));
-			$this->config->set('access-delete-' . $assetType, $this->juser->authorise('core.delete' . $at, $asset));
-			$this->config->set('access-edit-' . $assetType, $this->juser->authorise('core.edit' . $at, $asset));
-			$this->config->set('access-edit-state-' . $assetType, $this->juser->authorise('core.edit.state' . $at, $asset));
-			$this->config->set('access-edit-own-' . $assetType, $this->juser->authorise('core.edit.own' . $at, $asset));
 		}
 	}
 }
