@@ -31,32 +31,38 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-if ($this->getError())
-{
-	?>
+if ($this->getError()) { ?>
 	<p class="error"><?php echo JText::_('MOD_FEATUREDBLOG_MISSING_CLASS'); ?></p>
-	<?php
-}
-else if ($this->row)
-{
-	$row = new BlogModelEntry($this->row);
-	$base = rtrim(JURI::getInstance()->base(true), '/');
-	?>
+<?php } else {
+	$yearFormat  = "%Y";
+	$monthFormat = "%m";
+	$tz = 0;
+	if (version_compare(JVERSION, '1.6', 'ge'))
+	{
+		$yearFormat  = "Y";
+		$monthFormat = "m";
+		$tz = true;
+	}
+
+	if ($this->row) {
+		ximport('Hubzero_View_Helper_Html');
+?>
 	<div class="<?php echo $this->cls; ?>">
 		<p class="featured-img">
-			<a href="<?php echo JRoute::_($row->link()); ?>">
-				<img width="50" height="50" src="<?php echo $base; ?>/modules/mod_featuredblog/images/blog_thumb.gif" alt="<?php echo $this->escape(stripslashes($row->get('title'))); ?>" />
+			<a href="<?php echo JRoute::_('index.php?option=com_members&id=' . $this->row->created_by . '&active=blog&task=' . JHTML::_('date', $this->row->publish_up, $yearFormat, $tz) . '/' . JHTML::_('date', $this->row->publish_up, $monthFormat, $tz) . '/' . $this->row->alias); ?>">
+				<img width="50" height="50" src="/modules/mod_featuredblog/images/blog_thumb.gif" alt="<?php echo htmlentities(stripslashes($this->title)); ?>" />
 			</a>
 		</p>
 		<p>
-			<a href="<?php echo JRoute::_($row->link()); ?>">
-				<?php echo $this->escape(stripslashes($row->get('title'))); ?>
-			</a>:
-		<?php if ($row->get('content')) { ?>
-			<?php echo $row->content('clean', $this->txt_length); ?>
+			<a href="<?php echo JRoute::_('index.php?option=com_members&id=' . $this->row->created_by . '&active=blog&task=' . JHTML::_('date', $this->row->publish_up, $yearFormat, $tz) . '/' . JHTML::_('date', $this->row->publish_up, $monthFormat, $tz) . '/' . $this->row->alias); ?>">
+				<?php echo stripslashes($this->title); ?>
+			</a>: 
+		<?php if ($this->txt) { ?>
+			<?php echo Hubzero_View_Helper_Html::shortenText($this->encode_html(strip_tags($this->txt)), $this->txt_length, 0); ?>
 		<?php } ?>
 		</p>
 	</div>
-	<?php
+<?php
+	}
 }
 ?>
\ No newline at end of file
