@@ -31,35 +31,43 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
+jimport('joomla.plugin.plugin');
 jimport('joomla.filesystem.file');
 
 /**
  * Citations plugin class for bibtex
  */
-class plgCitationEndnote extends \Hubzero\Plugin\Plugin
+class plgCitationEndnote extends JPlugin
 {
 	/**
-	 * Affects constructor behavior. If true, language files will be loaded automatically.
-	 *
-	 * @var    boolean
+	 * Constructor
+	 * 
+	 * @param      object &$subject The object to observe
+	 * @param      array  $config   An optional associative array of configuration settings.
+	 * @return     void
 	 */
-	protected $_autoloadLanguage = true;
+	public function __construct(&$subject, $config)
+	{
+		parent::__construct($subject, $config);
+
+		$this->loadLanguage();
+	}
 
 	/**
 	 * Return file type
-	 *
+	 * 
 	 * @return     string HTML
 	 */
 	public function onImportAcceptedFiles()
 	{
-		return '.enw <small>(' . JText::_('PLG_CITATION_ENDNOTE_FILE') . ')</small>';
+		return '.enw <small>(EndNote File)</small>';
 	}
 
 	/**
 	 * Short description for 'onImport'
-	 *
+	 * 
 	 * Long description (if any) ...
-	 *
+	 * 
 	 * @param      array $file Parameter description (if any) ...
 	 * @return     unknown Return description (if any) ...
 	 */
@@ -72,7 +80,7 @@ class plgCitationEndnote extends \Hubzero\Plugin\Plugin
 		$file_info = pathinfo($file['name']);
 
 		//only process more in this file if it matches endnote format
-		if ($active != $file_info['extension'])
+		if ($active != $file_info['extension']) 
 		{
 			return;
 		}
@@ -86,16 +94,16 @@ class plgCitationEndnote extends \Hubzero\Plugin\Plugin
 
 	/**
 	 * Short description for 'onImportProcessEndnote'
-	 *
+	 * 
 	 * Long description (if any) ...
-	 *
+	 * 
 	 * @param      array $raw_citations_text Parameter description (if any) ...
 	 * @return     array Return description (if any) ...
 	 */
 	protected function onImportProcessEndnote($raw_citations_text)
 	{
 		//make sure we have some citation data to process
-		if (empty($raw_citations_text))
+		if (empty($raw_citations_text)) 
 		{
 			return;
 		}
@@ -103,19 +111,11 @@ class plgCitationEndnote extends \Hubzero\Plugin\Plugin
 		$raw_citation = array();
 		$raw_citations = array();
 
-		foreach ($raw_citations_text as $k => $line)
+		foreach ($raw_citations_text as $line)
 		{
-			// get this lines content
+			//$line = $this->_cleanText(trim($line));
 			$line = trim($line);
-
-			// check to see if we can get the next lines content
-			if(isset($raw_citations_text[$k + 1]))
-			{
-				$nextline = trim($raw_citations_text[$k + 1]);
-			}
-
-			// if we have two line breaks in a row that means next citation
-			if ($line == '' && $nextline == '')
+			if ($line == '')
 			{
 				$raw_citations[] = $raw_citation;
 				$raw_citation = array();
@@ -123,63 +123,54 @@ class plgCitationEndnote extends \Hubzero\Plugin\Plugin
 			}
 			$raw_citation[] = $line;
 		}
-
-		// append each citation as a single citation
 		$raw_citations[] = $raw_citation;
 
-		// remove empty citations
+		//remove empties
 		$raw_citations = array_values(array_filter($raw_citations));
 
-		foreach ($raw_citations as $k => $rc)
+		foreach ($raw_citations as $k => $rc) 
 		{
-			foreach ($rc as $r => $line)
+			foreach ($rc as $r => $line) 
 			{
+				//echo $line .'<br>';
 				$raw_citations[$k] .= $line . "\r\n";
 			}
 		}
 
-		// var to hold citation data
+		//vars used 
 		$citations = array();
 
-		// loop through each citations raw data
-		for ($i=0, $n=count($raw_citations); $i<$n; $i++)
+		//loop through each citations raw data
+		for ($i=0; $i<count($raw_citations); $i++) 
 		{
 			//split citation data match % sign followed by char
-			//$citation_data = preg_split('/%.\s{1}/', $raw_citations[$i], NULL, PREG_SPLIT_OFFSET_CAPTURE);
-			$citation_data = preg_split('/%.{1}/', $raw_citations[$i], NULL, PREG_SPLIT_OFFSET_CAPTURE);
+			$citation_data = preg_split('/%.\s{1}/', $raw_citations[$i], NULL, PREG_SPLIT_OFFSET_CAPTURE);
 
 			//array to hold each citation
 			$citation = array();
 
 			//build array of citation data
-			foreach ($citation_data as $cd)
+			foreach ($citation_data as $cd) 
 			{
-				if (!empty($cd[0]))
+				if (!empty($cd[0])) 
 				{
-					//$key = substr($raw_citations[$i], ($cd[1]-3), 2);
-					$key = substr($raw_citations[$i], ($cd[1]-2), 2);
-					if (array_key_exists($key, $citation))
+					$key = substr($raw_citations[$i], ($cd[1]-3), 2);
+					if (array_key_exists($key, $citation)) 
 					{
 						switch($key)
 						{
+							//case "%A": $citation[$key] .= "; " . htmlentities(trim($cd[0])); break;
+							//case "%E": $citation[$key] .= "; " . htmlentities(trim($cd[0])); break;
+							//case "%Z": $citation[$key] .= "\n" . htmlentities(trim($cd[0])); break;
 							case "%A": $citation[$key] .= "; " . htmlspecialchars(trim($cd[0])); break;
 							case "%E": $citation[$key] .= "; " . htmlspecialchars(trim($cd[0])); break;
 							case "%Z": $citation[$key] .= "\n" . htmlspecialchars(trim($cd[0])); break;
 						}
-					}
-					else
+					} 
+					else 
 					{
-						if($key == "%K")
-						{
-							$keywords = str_replace(",", " ", $cd[0]);
-							$keywords = str_replace("\r\n", "\n", $keywords);
-							$keywords = preg_replace('/[\r|\n|\r\n]/', ",\n", $keywords);
-							$citation[$key] = $keywords;
-						}
-						else
-						{
-							$citation[$key] = htmlspecialchars(trim($cd[0]));
-						}
+						//$citation[$key] = htmlentities(trim($cd[0]));
+						$citation[$key] = htmlspecialchars(trim($cd[0]));
 					}
 				}
 			}
@@ -197,56 +188,37 @@ class plgCitationEndnote extends \Hubzero\Plugin\Plugin
 		$final_citations = array();
 
 		//loop through the split up citations
-		foreach ($citations as $citation)
+		foreach ($citations as $citation) 
 		{
 			$cite = array();
-			foreach($endnote_tags as $tag => $keys)
+			foreach ($endnote_tags as $k => $v) 
 			{
-				//loop through each key, we might have more than one key that we want as a var (ie. %K & %< to be tags)
-				foreach($keys as $key)
+				//make sure the var exists in our citation
+				if (array_key_exists($v, $citation)) 
 				{
-					// make sure to remove unwanted space
-					$key = trim($key);
+					$cite[$k] = $citation[$v];
+				}
 
-					//make sure the var exists in our citation
-					if(array_key_exists($key, $citation))
-					{
-						// trim the value
-						$value = trim(trim($citation[$key],':;,'));
-
-						//append the data if we have already set that variable
-						if(isset($cite[$tag]))
-						{
-							$cite[$tag] .= "\n" . $value;
-						}
-						else
-						{
-							$cite[$tag] = $value;
-						}
-					}
+				//if we have fields in our imported citation data that dont exist in the database report errors
+				if (!in_array($k, $citation_vars) && array_key_exists($v, $citation)) 
+				{
+					$cite['errors'][] = "Failed to add '{$k}' to this citation.";
 				}
 			}
-			// make sure all tags are separated by comma
-			if (isset($cite['tags']))
-			{
-				$cite['tags'] = str_replace("\n", ',', $cite['tags']);
-				$cite['tags'] = str_replace(',,', ',', $cite['tags']);
-			}
-
 			$final_citations[] = $cite;
 		}
 
 		//check for duplicates
-		for ($i = 0; $i < count($final_citations); $i++)
+		for ($i = 0; $i < count($final_citations); $i++) 
 		{
 			$duplicate = $this->checkDuplicateCitation($final_citations[$i]);
 
-			if ($duplicate)
+			if ($duplicate) 
 			{
 				$final_citations[$i]['duplicate'] = $duplicate;
 				$final['attention'][] = $final_citations[$i];
-			}
-			else
+			} 
+			else 
 			{
 				$final_citations[$i]['duplicate'] = 0;
 				$final['no_attention'][] = $final_citations[$i];
@@ -258,9 +230,9 @@ class plgCitationEndnote extends \Hubzero\Plugin\Plugin
 
 	/**
 	 * Short description for 'getCitationVars'
-	 *
+	 * 
 	 * Long description (if any) ...
-	 *
+	 * 
 	 * @return     array Return description (if any) ...
 	 */
 	protected function getCitationVars()
@@ -269,9 +241,9 @@ class plgCitationEndnote extends \Hubzero\Plugin\Plugin
 		$keys = array_keys(get_class_vars('CitationsCitation'));
 
 		//remove any private vars
-		foreach ($keys as $k => $v)
+		foreach ($keys as $k => $v) 
 		{
-			if (substr($v,0,1) == '_')
+			if (substr($v,0,1) == '_') 
 			{
 				unset($keys[$k]);
 			}
@@ -283,41 +255,41 @@ class plgCitationEndnote extends \Hubzero\Plugin\Plugin
 
 	/**
 	 * Short description for 'getEndnoteTags'
-	 *
+	 * 
 	 * Long description (if any) ...
-	 *
+	 * 
 	 * @return     array Return description (if any) ...
 	 */
 	protected function getEndnoteTags()
 	{
 		$tags = array(
-			'author'           => array('%A'),
-			'booktitle'        => array('%B'),
-			'address'          => array('%C'),
-			'year'             => array('%D'),
-			'editor'           => array('%E'),
-			'label'            => array('%F'),
-			'language'         => array('%G'),
-			'publisher'        => array('%I'),
-			'journal'          => array('%J'),
-			'keywords'         => array('%K'),
-			'call_number'      => array('%L'),
-			'accession_number' => array('%M'),
-			'number'           => array('%N'),
-			'pages'            => array('%P'),
-			'doi'              => array('%R'),
-			'title'            => array('%T'),
-			'url'              => array('%U'),
-			'volume'           => array('%V'),
-			'abstract'         => array('%X'),
-			'notes'            => array('%Z'),
-			'type'             => array('%0'),
-			'edition'          => array('%7'),
-			'month'            => array('%8'),
-			'isbn'             => array('%@'),
-			'short_title'      => array('%!'),
-			'author_address'   => array('%+'),
-			'research_notes'   => array('%<')
+			'author'           => '%A',
+			'editor'           => '%E',
+			'type'             => '%0',
+			'journal'          => '%J',
+			'booktitle'        => '%B',
+			'title'            => '%T',
+			'address'          => '%C',
+			'publisher'        => '%I',
+			'number'           => '%N',
+			'pages'            => '%P',
+			'url'              => '%U',
+			'volume'           => '%V',
+			'notes'            => '%Z',
+			'edition'          => '%7',
+			'month'            => '%8',
+			'year'             => '%D',
+			'isbn'             => '%@',
+			'doi'              => '%1',
+			'abstract'         => '%X',
+			'keywords'         => '%K',
+			'label'            => '%F',
+			'language'         => '%G',
+			'call_number'      => '%L',
+			'accession_number' => '%M',
+			'short_title'      => '%!',
+			'research_notes'   => '%<',
+			'author_address'   => '%+'
 		);
 
 		//get any custom tags that we want to use
@@ -325,19 +297,12 @@ class plgCitationEndnote extends \Hubzero\Plugin\Plugin
 		$custom_tags = explode("\n", $custom_tags);
 
 		//loop through each custom tag in the parameter and add it to the tag list
-		foreach ($custom_tags as $ct)
+		foreach ($custom_tags as $ct) 
 		{
-			if ($ct)
+			if ($ct) 
 			{
 				$parts = explode('-', $ct);
-				if(in_array($parts[0], array_keys($tags)))
-				{
-					$tags[$parts[0]][] = $parts[1];
-				}
-				else
-				{
-					$tags[$parts[0]] = array($parts[1]);
-				}
+				$tags[$parts[0]] = $parts[1];
 			}
 		}
 
@@ -347,19 +312,19 @@ class plgCitationEndnote extends \Hubzero\Plugin\Plugin
 
 	/**
 	 * Short description for 'checkDuplicateCitation'
-	 *
+	 * 
 	 * Long description (if any) ...
-	 *
+	 * 
 	 * @param      array $citation Parameter description (if any) ...
 	 * @return     integer Return description (if any) ...
 	 */
 	protected function checkDuplicateCitation($citation)
 	{
 		//vars
-		$title = '';
-		$doi = '';
-		$isbn = '';
-		$match = 0;
+		$title = ''; 
+		$doi = ''; 
+		$isbn = ''; 
+		$match = 0; 
 		$title_does_match = false;
 
 		//default percentage to match title
@@ -375,7 +340,7 @@ class plgCitationEndnote extends \Hubzero\Plugin\Plugin
 		$title_match = ($title_match == 0) ? $default_title_match : $title_match;
 
 		//database object
-		$db = JFactory::getDBO();
+		$db =& JFactory::getDBO();
 
 		//query
 		$sql = "SELECT id, title, doi, isbn FROM #__citations";
@@ -387,7 +352,7 @@ class plgCitationEndnote extends \Hubzero\Plugin\Plugin
 		$result = $db->loadObjectList();
 
 		//loop through all current citations
-		foreach ($result as $r)
+		foreach ($result as $r) 
 		{
 			$id    = $r->id;
 			$title = $r->title;
@@ -396,27 +361,27 @@ class plgCitationEndnote extends \Hubzero\Plugin\Plugin
 
 			//match titles based on percect param
 			similar_text($title, $citation['title'], $similar);
-			if ($similar >= $title_match)
+			if ($similar >= $title_match) 
 			{
 				$title_does_match = true;
 			}
 
 			//direct matches on doi
-			if (isset($citation['doi']) && ($doi == $citation['doi']) && ($doi != '' && $title_does_match))
+			if (isset($citation['doi']) && ($doi == $citation['doi']) && ($doi != '' && $title_does_match)) 
 			{
 				$match = $id;
 				break;
 			}
 
 			//direct matches on isbn
-			if (isset($citation['isbn']) && ($isbn == $citation['isbn']) && ($isbn != '' && $title_does_match))
+			if (isset($citation['isbn']) && ($isbn == $citation['isbn']) && ($isbn != '' && $title_does_match)) 
 			{
 				$match = $id;
 				break;
 			}
 
 			//
-			if ($title_does_match)
+			if ($title_does_match) 
 			{
 				$match = $id;
 				break;
@@ -428,9 +393,9 @@ class plgCitationEndnote extends \Hubzero\Plugin\Plugin
 
 	/**
 	 * Short description for '_cleanText'
-	 *
+	 * 
 	 * Long description (if any) ...
-	 *
+	 * 
 	 * @param      unknown $string Parameter description (if any) ...
 	 * @return     unknown Return description (if any) ...
 	 */
