@@ -58,7 +58,7 @@ class plgResourcesFavorite extends JPlugin
 	 * @param      object $resource Current resource
 	 * @return     array
 	 */
-	public function onResourcesAreas($model)
+	public function onResourcesAreas($resource)
 	{
 		return array();
 	}
@@ -72,13 +72,13 @@ class plgResourcesFavorite extends JPlugin
 	 * @param      string  $rtrn      Data to be returned
 	 * @return     array
 	 */
-	public function onResources($model, $option, $areas, $rtrn='all')
+	public function onResources($resource, $option, $areas, $rtrn='all')
 	{
 		// Check if our area is in the array of areas we want to return results for
 		if (is_array($areas)) 
 		{
-			if (!array_intersect($areas, $this->onResourcesAreas($model))
-			 && !array_intersect($areas, array_keys($this->onResourcesAreas($model)))) 
+			if (!array_intersect($areas, $this->onResourcesAreas($resource))
+			 && !array_intersect($areas, array_keys($this->onResourcesAreas($resource)))) 
 			{
 				$rtrn = 'metadata';
 			}
@@ -89,7 +89,7 @@ class plgResourcesFavorite extends JPlugin
 		if ($action && $action == 'favorite') 
 		{
 			// Check the user's logged-in status
-			$this->fav($model->resource->id);
+			$this->fav($resource->id);
 		}
 
 		$arr = array(
@@ -99,18 +99,25 @@ class plgResourcesFavorite extends JPlugin
 		);
 
 		// Build the HTML meant for the "about" tab's metadata overview
-		$juser = JFactory::getUser();
+		$juser =& JFactory::getUser();
 		if (!$juser->get('guest')) 
 		{
 			if ($rtrn == 'all' || $rtrn == 'metadata') 
 			{
 				// Push some scripts to the template
-				\Hubzero\Document\Assets::addPluginScript('resources', 'favorite');
+				ximport('Hubzero_Document');
+				Hubzero_Document::addPluginScript('resources', 'favorite');
 
-				$database = JFactory::getDBO();
+				ximport('Hubzero_Favorite');
+				if (!class_exists('Hubzero_Favorite')) 
+				{
+					return $arr;
+				}
 
-				$fav = new \Hubzero\Item\Favorite($database);
-				$fav->loadFavorite($juser->get('id'), $model->resource->id, 'resources');
+				$database =& JFactory::getDBO();
+
+				$fav = new Hubzero_Favorite($database);
+				$fav->loadFavorite($juser->get('id'), $resource->id, 'resources');
 				if (!$fav->id) 
 				{
 					$txt = JText::_('PLG_RESOURCES_FAVORITES_FAVORITE_THIS');
@@ -122,7 +129,8 @@ class plgResourcesFavorite extends JPlugin
 					$cls = 'faved';
 				}
 
-				$view = new \Hubzero\Plugin\View(
+				ximport('Hubzero_Plugin_View');
+				$view = new Hubzero_Plugin_View(
 					array(
 						'folder'  => 'resources',
 						'element' => 'favorite',
@@ -132,7 +140,7 @@ class plgResourcesFavorite extends JPlugin
 				$view->cls = $cls;
 				$view->txt = $txt;
 				$view->option = $option;
-				$view->resource = $model->resource;
+				$view->resource = $resource;
 				$arr['metadata'] = $view->loadTemplate();
 			}
 		}
@@ -148,11 +156,6 @@ class plgResourcesFavorite extends JPlugin
 	 */
 	public function onResourcesFavorite($option)
 	{
-		if (JRequest::getWord('active', '') != 'favorite')
-		{
-			return;
-		}
-
 		$rid = JRequest::getInt('rid', 0);
 
 		$arr = array('html' => '');
@@ -171,12 +174,14 @@ class plgResourcesFavorite extends JPlugin
 	 */
 	public function fav($oid)
 	{
-		$juser = JFactory::getUser();
+		$juser =& JFactory::getUser();
 		if (!$juser->get('guest')) 
 		{
-			$database = JFactory::getDBO();
+			ximport('Hubzero_Favorite');
 
-			$fav = new \Hubzero\Item\Favorite($database);
+			$database =& JFactory::getDBO();
+
+			$fav = new Hubzero_Favorite($database);
 			$fav->loadFavorite($juser->get('id'), $oid, 'resources');
 
 			if (!$fav->id) 
@@ -184,7 +189,7 @@ class plgResourcesFavorite extends JPlugin
 				$fav->uid = $juser->get('id');
 				$fav->oid = $oid;
 				$fav->tbl = 'resources';
-				$fav->faved = JFactory::getDate()->toSql();
+				$fav->faved = date('Y-m-d H:i:s');
 				$fav->check();
 				$fav->store();
 
